/* last modified 09/16/05 */
/*
 *******************************************************************************
 *                                                                             *
 *   EvaluatePieces() is used to evaluate all pieces other than pawns, but     *
 *   does not include some piece-related things like development and king-     *
 *   safety as it relates to castling.                                         *
 *                                                                             *
 *******************************************************************************
 */
int EvaluateKings(TREE * RESTRICT tree)
{
  register BITBOARD temp;
  register int square, file, tscore;
  register int score=0;
/*
 ************************************************************
 *                                                          *
 *   white king.                                            *
 *                                                          *
 *   first, check for where the king should be if this is   *
 *   an endgame.  ie with pawns on one wing, the king needs *
 *   to be on that wing.  with pawns on both wings, the     *
 *   king belongs in the center.                            *
 *                                                          *
 ************************************************************
 */
  if (tree->endgame) {
    if (tree->all_pawns & mask_efgh && tree->all_pawns & mask_abcd)
      score += kval_wn[WhiteKingSQ];
    else if (tree->all_pawns & mask_efgh)
      score += kval_wk[WhiteKingSQ];
    else if (tree->all_pawns)
      score += kval_wq[WhiteKingSQ];
  }
/*
 ************************************************************
 *                                                          *
 *   check to see if the king has been forced to move and   *
 *   has trapped a rook at a1/a2/b1/g1/h1/h2, if so, then   *
 *   penalize the trapped rook to help extricate it.        *
 *                                                          *
 ************************************************************
 */
  if (WhiteKingSQ < A2) {
    if (WhiteKingSQ > E1) {
      if (WhiteRooks & mask_kr_trapped_w[FILEH - WhiteKingSQ])
        score -= rook_trapped;
    } else if (WhiteKingSQ < D1) {
      if (WhiteRooks & mask_qr_trapped_w[WhiteKingSQ])
        score -= rook_trapped;
    }
  }
#ifdef DEBUGEV
  printf("score[kings(white)]=              %4d\n", score);
#endif

/*
 ************************************************************
 *                                                          *
 *   black king.                                            *
 *                                                          *
 *   first, check for where the king should be if this is   *
 *   an endgame.  ie with pawns on one wing, the king needs *
 *   to be on that wing.  with pawns on both wings, the     *
 *   king belongs in the center.                            *
 *                                                          *
 ************************************************************
 */
  if (tree->endgame) {
    if (tree->all_pawns & mask_efgh && tree->all_pawns & mask_abcd)
      score -= kval_bn[BlackKingSQ];
    else if (tree->all_pawns & mask_efgh)
      score -= kval_bk[BlackKingSQ];
    else if (tree->all_pawns)
      score -= kval_bq[BlackKingSQ];
  }
/*
 ************************************************************
 *                                                          *
 *   check to see if the king has been forced to move and   *
 *   has trapped a rook at a8/a7/b8/g7/h8/h7, if so, then   *
 *   penalize the trapped rook to help extricate it.        *
 *                                                          *
 ************************************************************
 */
  if (BlackKingSQ > H7) {
    if (BlackKingSQ > E8) {
      if (BlackRooks & mask_kr_trapped_b[FILEH - File(BlackKingSQ)])
        score += rook_trapped;
    } else if (BlackKingSQ < D8) {
      if (BlackRooks & mask_qr_trapped_b[File(BlackKingSQ)])
        score += rook_trapped;
    }
  }
#ifdef DEBUGEV
  printf("score[kings(black)]=              %4d\n", score);
#endif
  return (score);
}
