/* last modified 09/16/05 */
/*
 *******************************************************************************
 *                                                                             *
 *   EvaluatePieces() is used to evaluate all pieces other than pawns, but     *
 *   does not include some piece-related things like development and king-     *
 *   safety as it relates to castling.                                         *
 *                                                                             *
 *******************************************************************************
 */
int EvaluateKnight(TREE * RESTRICT tree)
{
  register BITBOARD temp;
  register int square, file, tscore;
  register int score=0;
/*
 **********************************************************************
 *                                                                    *
 *   knight evaluation includes centralization and "outposts".        *
 *                                                                    *
 **********************************************************************
 */
/*
 ************************************************************
 *                                                          *
 *   white knights.                                         *
 *                                                          *
 *   first, evaluate for "outposts" which is a knight that  *
 *   can't be driven off by an enemy pawn, and which is     *
 *   supported by a friendly pawn.  an outpost is much      *
 *   stronger if it is supported by two pawns (capturing it *
 *   results in a protected passed pawn) or if the opponent *
 *   has no minor piece that can attack it.                 *
 *                                                          *
 ************************************************************
 */
  temp = WhiteKnights;
  while (temp) {
    square = FirstOne(temp);
    if (white_outpost[square] && !(mask_no_pattacks_b[square] & BlackPawns))
      score += white_outpost[square];
    if ((square == D6 || square == E6) && PcOnSq(square + 8) == -pawn)
      score += blocked_center_pawn;
/*
 ************************************************************
 *                                                          *
 *   now fold in centralization score from the piece/square *
 *   table "nval_*".                                        *
 *                                                          *
 ************************************************************
 */
    score += nval_w[square];
/*
 ************************************************************
 *                                                          *
 *   adjust the white tropism count for this piece.         *
 *                                                          *
 ************************************************************
 */
    tree->w_tropism += king_tropism_n[Distance(square, tree->b_kingsq)];
    Clear(square, temp);
  }
#ifdef DEBUGEV
  printf("score[knights(white)]=            %4d\n", score);
#endif
/*
 ************************************************************
 *                                                          *
 *   black knights.                                         *
 *                                                          *
 *   first, evaluate for "outposts" which is a knight that  *
 *   can't be driven off by an enemy pawn, and which is     *
 *   supported by a friendly pawn.  an outpost is much      *
 *   stronger if it is supported by two pawns (capturing it *
 *   results in a protected passed pawn) or if the opponent *
 *   has no minor piece that can attack it.                 *
 *                                                          *
 ************************************************************
 */
  temp = BlackKnights;
  while (temp) {
    square = FirstOne(temp);
    if (black_outpost[square] && !(mask_no_pattacks_w[square] & WhitePawns))
      score -= black_outpost[square];
    if ((square == D3 || square == E3) && PcOnSq(square - 8) == pawn)
      score -= blocked_center_pawn;
/*
 ************************************************************
 *                                                          *
 *   now fold in centralization score from the piece/square *
 *   table "nval_*".                                        *
 *                                                          *
 ************************************************************
 */
    score -= nval_b[square];
/*
 ************************************************************
 *                                                          *
 *   adjust the black tropism count for this piece.         *
 *                                                          *
 ************************************************************
 */
    tree->b_tropism += king_tropism_n[Distance(square, tree->w_kingsq)];
    Clear(square, temp);
  }
#ifdef DEBUGEV
  printf("score[knights(black)]=            %4d\n", score);
#endif
  return (score);
}
