
/* last modified 09/16/05 */
/*
 *******************************************************************************
 *                                                                             *
 *   EvaluatePieces() is used to evaluate all pieces other than pawns, but     *
 *   does not include some piece-related things like development and king-     *
 *   safety as it relates to castling.                                         *
 *                                                                             *
 *******************************************************************************
 */
int EvaluatePieces(TREE * RESTRICT tree, int wtm)
{
  register BITBOARD temp;
  register int square, file, tscore, w_tropism = 0, b_tropism = 0;
  register int trop;
  register int score=0;
/*
 **********************************************************************
 *                                                                    *
 *  now evaluate the pieces by calling the specific piece evaluation  *
 *  procedures (in no particular order).                              *
 *                                                          *
 ************************************************************
 */
  score += EvaluateKnights(tree);
  score += EvaluateBishops(tree);
  score += EvaluateRooks(tree);
  score += EvaluateQueens(tree);
  score += EvaluateKings(tree);
/*
 ************************************************************
 *                                                          *
 *   now fold in the king tropism score, which take into    *
 *   account _all_ pieces for each side that are close to   *
 *   the opponent's king. the calculation uses three values *
 *   for each side.  the 'total tropism' number, multiplied *
 *   by the opponent's king safety, but this is first run   *
 *   through an indirect table probe to get a multiplier    *
 *   value.  the ttemper[] array provides a number between  *
 *   16 and N, where 16 says use all the tropism numbers,   *
 *   32 says to double the tropism scores (ie this array is *
 *   specified in units of 1/16th).                         *
 *                                                          *
 ************************************************************
 */
  if (!tree->endgame)
    score +=
        ((tropism[tree->w_tropism + 8] * ttemper[tree->b_safety]) >> 4) -
        ((tropism[tree->b_tropism + 8] * ttemper[tree->w_safety]) >> 4);
#ifdef DEBUGEV
  printf("score[king tropism]=              %4d\n", score);
  printf("w_safety=%d  b_safety=%d\n", tree->w_safety, tree->b_safety);
  printf("w_tropism=%d  b_tropism=%d\n", tree->w_tropism, tree->b_tropism);
  printf("wtrop.score=%d\n",
      (tropism[w_tropism + 8] * ttemper[tree->b_safety]) >> 4);
  printf("btrop.score=%d\n",
      (tropism[b_tropism + 8] * ttemper[tree->w_safety]) >> 4);
#endif
  return (score);
}
